/***************************************************************
* L&L - Labyrinths & Legends
* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
* 
* Created by BowKenKen
*   URL: https://sourceforge.jp/projects/lnl/
* 
* License is GPL
* 
* ܥץϥե꡼եȥǤ
* ʤϡ Free Software Foundation ɽ
*  GNU ̸ͭѵΡ֥С󣲡
* ϤʹߤγƥС椫餤줫򤷡
* ΥС˽äܥץ
* ۤޤѹ뤳ȤǤޤ
* 
* ܥץͭѤȤϻפޤۤˤäƤϡ
* ԾڤŪŬˤĤƤΰۤݾڤޤ,
* ʤݾڤԤʤޤ
* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
* 
* ʤϡܥץȰ GNU ̸ͭѵ
* μ̤äƤϤǤǤʤϡ
*   Free Software Foundation, Inc.,
*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
* ؼ񤤤Ƥ
* 
* $Id: GuiMessage.h,v 1.20 2008/05/02 12:00:35 bowkenken Exp $
***************************************************************/

#ifndef GUI_MESSAGE_H
#define GUI_MESSAGE_H	1

////////////////////////////////////////////////////////////////
// åɥ
////////////////////////////////////////////////////////////////

#define GUI_MESSAGE_CPP
#include "inc.h"

////////////////////////////////////////////////////////////////

class GuiMessage {

	//////// ץ饤١ȡСѿ ////////
private:

	bool flagMore;

#ifdef D_WS
#endif // D_WS

#ifdef D_GTK
	gint nPreX, nPreY, nPreW, nPreH;
	GtkWidget *mMessageDrawingArea;
	GtkWidget *mMessageHScrollBar;
	GtkWidget *mMessageVScrollBar;
	GtkObject *mMessageHScrollBarAdjustment;
	GtkObject *mMessageVScrollBarAdjustment;

	GdkGC *mFgGc;
	GdkGC *mBgGc;
	GtkStyle *mStyle;
#endif // D_GTK

#ifdef D_MFC
	CClientDC *pDc;
#endif // D_MFC

	//////// ѥ֥åСѿ ////////
public:

	// Դֳ
	static const long LINE_INTERVAL = 1;
	long mLsMessageDrawBeginN;
	long mLsMessageDrawN;

#ifdef D_WS
#endif // D_WS

#ifdef D_GTK
	GtkWidget *mMessageWin;
#endif // D_GTK

#ifdef D_MFC
	class CMessageWnd *mMessageWin;
#endif // D_MFC

	//////// ѥ֥åСؿ ////////
public:

	GuiMessage();
	~GuiMessage();

	void init();
	void destroy();

	void setFlagMore( bool flag );

	void redraw();
	void draw( bool flagRedraw );
	void wipe();
	void drawScrollBar();

	void hScroll( long n );
	void vScroll( long n );

	//////// ץ饤١ȡСؿ ////////
private:

	void newWin();
};

#endif /* GUI_MESSAGE_H */
